pub enum Outcome {
Success,
Failure,
}Expand description
Classification supplied by the caller after a request completes.
Variants
Success
The response represents healthy work for this endpoint.
Failure
The response, transport error, timeout, or cancellation is unhealthy.